from .chains import (
    ethereum,
    avalanche,
    fantom,
    arbitrum,
    bsc,
    optimism,
    polygon,
)
from .explorer import (
    etherscan,
    snowtrace,
    ftmscan,
    arbiscan,
    bscscan,
    optimistic_etherscan,
    polygonscan,
)


CHAIN_TO_EXPLORER = {
    ethereum: etherscan,
    avalanche: snowtrace,
    fantom: ftmscan,
    arbitrum: arbiscan,
    bsc: bscscan,
    optimism: optimistic_etherscan,
    polygon: polygonscan,
}



import time

from core.contract import Contract
from core.explorer import etherscan
from core.chains import ethereum

usdt_address = "0xdaC17F958D2ee523a2206206994597C13D831ec7"
usdt = Contract(usdt_address, ethereum)
print(
    "USDT balance of USDT (burned funds):",
    usdt.balanceOf(usdt_address, block=15255547) / 10 ** usdt.decimals(block=15255547),
)

time.sleep(5)

timestamp = int(time.time())
block = etherscan.block.getblocknobytime(timestamp=timestamp, closest="before")
print(block, ethereum.eth.block_number)



from web3 import Web3


def chain_w3(rpc):
    return Web3(Web3.HTTPProvider(rpc))


ethereum = chain_w3("https://rpc.ankr.com/eth")
avalanche = chain_w3("https://rpc.ankr.com/avalanche-c")
fantom = chain_w3("https://rpc.ankr.com/fantom")
arbitrum = chain_w3("https://rpc.ankr.com/arbitrum")
bsc = chain_w3("https://rpc.ankr.com/bsc")
optimism = chain_w3("https://rpc.ankr.com/optimism")
polygon = chain_w3("https://rpc.ankr.com/polygon")
